<?php
  /**
   * @file
   * Default theme implementation to display a single Drupal page.
   *
   * The doctype, html, head and body tags are not in this template. Instead they
   * can be found in the html.tpl.php template in this directory.
   *
   * Available variables:
   *
   * General utility variables:
   * - $base_path: The base URL path of the Drupal installation. At the very
   *   least, this will always default to /.
   * - $directory: The directory the template is located in, e.g. modules/system
   *   or themes/bartik.
   * - $is_front: TRUE if the current page is the front page.
   * - $logged_in: TRUE if the user is registered and signed in.
   * - $is_admin: TRUE if the user has permission to access administration pages.
   *
   * Site identity:
   * - $front_page: The URL of the front page. Use this instead of $base_path,
   *   when linking to the front page. This includes the language domain or
   *   prefix.
   * - $logo: The path to the logo image, as defined in theme configuration.
   * - $site_name: The name of the site, empty when display has been disabled
   *   in theme settings.
   * - $site_slogan: The slogan of the site, empty when display has been disabled
   *   in theme settings.
   *
   * Navigation:
   * - $main_menu (array): An array containing the Main menu links for the
   *   site, if they have been configured.
   * - $secondary_menu (array): An array containing the Secondary menu links for
   *   the site, if they have been configured.
   * - $breadcrumb: The breadcrumb trail for the current page.
   *
   * Page content (in order of occurrence in the default page.tpl.php):
   * - $title_prefix (array): An array containing additional output populated by
   *   modules, intended to be displayed in front of the main title tag that
   *   appears in the template.
   * - $title: The page title, for use in the actual HTML content.
   * - $title_suffix (array): An array containing additional output populated by
   *   modules, intended to be displayed after the main title tag that appears in
   *   the template.
   * - $messages: HTML for status and error messages. Should be displayed
   *   prominently.
   * - $tabs (array): Tabs linking to any sub-pages beneath the current page
   *   (e.g., the view and edit tabs when displaying a node).
   * - $action_links (array): Actions local to the page, such as 'Add menu' on the
   *   menu administration interface.
   * - $feed_icons: A string of all feed icons for the current page.
   * - $node: The node object, if there is an automatically-loaded node
   *   associated with the page, and the node ID is the second argument
   *   in the page's path (e.g. node/12345 and node/12345/revisions, but not
   *   comment/reply/12345).
   *
   * Regions:
   * - $page['help']: Dynamic help text, mostly for admin pages.
   * - $page['highlighted']: Items for the highlighted content region.
   * - $page['content']: The main content of the current page.
   * - $page['sidebar_first']: Items for the first sidebar.
   * - $page['sidebar_second']: Items for the second sidebar.
   * - $page['header']: Items for the header region.
   * - $page['footer']: Items for the footer region.
   *
   * @see bootstrap_preprocess_page()
   * @see template_preprocess()
   * @see template_preprocess_page()
   * @see bootstrap_process_page()
   * @see template_process()
   * @see html.tpl.php
   *
   * @ingroup templates
   */
  ?>
<header class="app-header navbar">
  <button class="navbar-toggler sidebar-toggler d-lg-none mr-auto" type="button" data-toggle="sidebar-show">
  <span class="navbar-toggler-icon"></span>
  </button>
  <?php if ($logo): ?>    
  <a class="navbar-brand" href="<?php print $front_page; ?>">
  <img class="navbar-brand-full"  src="<?php print $logo; ?>" width="89" height="25" alt="<?php print t('Home'); ?>">
  <img class="navbar-brand-minimized"  src="/assets/img/brand/sygnet.png" width="30" height="30" alt="<?php print t('Home'); ?>">
  </a>
  <?php endif; ?>
    <?php if (!empty($primary_nav)): ?>
    <?php print render($primary_nav); ?>
  <?php endif; ?>
  <?php if (!empty($page['navigation'])): ?>
   <?php print render($page['navigation']); ?>
  <?php endif; ?>
  <button class="navbar-toggler sidebar-toggler d-md-down-none pull-left" type="button" data-toggle="sidebar-lg-show">
  <span class="navbar-toggler-icon"></span>
  </button>
          <?php if (!empty($secondary_nav)): ?>
            <?php print render($secondary_nav); ?>
          <?php endif; ?>
</header>
<div class="app-body">
  <div id="sidebar-first" class="sidebar">
    <nav class="sidebar-nav">
      <?php if (!empty($page['sidebar_first'])): ?>
      <?php print render($page['sidebar_first']); ?>
      <?php endif; ?>  
    </nav>
    <button class="sidebar-minimizer brand-minimizer" type="button"></button> 
  </div>
  <main class="main">
    <!-- Breadcrumb-->
    <?php if (!empty($breadcrumb)): print $breadcrumb; endif;?>
    <div class="container-fluid">
      <div class="animated fadeIn">
        <div class="row">
          <div class="col-12">
            <div class="alert alert-warning alert-dismissible fade show" role="alert">
              <?php print $messages; ?>
              <button type="button" class="close" data-dismiss="alert" aria-label="Close">
              <span aria-hidden="true">x</span>
              </button>
            </div>
            <?php if (!empty($page['help'])): ?>
            <?php print render($page['help']); ?>
            <?php endif; ?>
            <div class="card">
              <div class="card-header">
                <div class="row">
                  <div class="col-12 col-sm-12 col-md-6 col-lg-6 col-xl-6">
                    <?php print render($title_prefix); ?>
                    <?php if (!empty($title)): ?>
                    <h1 class="page-header"><?php print $title; ?></h1>
                    <?php endif; ?>
                    <?php print render($title_suffix); ?>
                  </div>
                  <div class="col-12 col-sm-12 col-md-6 col-lg-6 col-xl-6">
                    <!-- Custom Data Can be added here -->
                  </div>
                </div>
              </div>
              <div class="card-body">
                <?php if (!empty($tabs)): ?>
                <?php print render($tabs); ?>
                <?php endif; ?>
                <?php if (!empty($action_links)): ?>
                <ul class="action-links"><?php print render($action_links); ?></ul>
                <?php endif; ?>       
                <?php print render($page['content']); ?>
              </div>
              <div class="card-footer">
                <?php print render($page['content_bottom']); ?>
              </div>
            </div>
          </div>
        </div>
      </div>
    </div>
  </main>
</div>
<footer class="app-footer">
  <div>
    <span>&copy; <?php echo date("Y"); ?></span> <a href="<?php print $front_page;?>"><?php print $site_name;?></a>
  </div>
  <div class="ml-auto">
    <?php if (!empty($page['footer_right'])): ?>
    <?php print render($page['footer_right']); ?>
    <?php endif; ?>
  </div>
</footer>